#!/bin/sh
###############################################################################
# IBM Confidential
# OCO Source Materials
# © Copyright IBM Corporation 2015
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with
# the U.S. Copyright office.
###############################################################################
error() {
    echo
    echo $1
    echo
    exit 1
}

syntax() {
    echo "Loads ${PACK} pack example resources exported from a Windows install"
    echo
    echo "spesetupsamples-pack${PACK}.sh"
    echo
}

if [ -z "$InSPEEnv" ]; then
    echo Please initialize the SPE environment before running this command.
    echo You can use spesetup.sh to initialize the environment.
else
    PACK=hc
    
    if  [ "$1" = "--h" ] || [ "$1" = "/?" ]
    then
        syntax
        exit
    fi
    
    # import ${PACK} resources
    cd ${SPE_INSTALL_DIR}
    DBPROPS="dbprops=${SPE_INSTALL_DIR}/dbprops.cfg"
    RESULT="Could not find any ${PACK} pack example files"
    
    # import ${PACK} ${STANDARD} resources
    STANDARD=hipaa
    echo
    echo Loading ${PACK} ${STANDARD} pack example resources
    echo

    # import ${PACK} ${STANDARD} deenvelope resources
    if [ -d "${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/deenvelope/import" ]
    then
        java com.ibm.spe.core.utils.SPEImporter ${DBPROPS} quiet -import="${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/deenvelope/import"
        if [ $? -ne 0 ]
        then
            error "There was an error while loading ${PACK} ${STANDARD} deenvelope import file"
        fi       
    fi
    
    # import ${PACK} ${STANDARD} docextract resources
    if [ -d "${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/docextract/import" ]
    then
        java com.ibm.spe.core.utils.SPEImporter ${DBPROPS} quiet -import="${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/docextract/import"
        if [ $? -ne 0 ]
        then
            error "There was an error while loading ${PACK} ${STANDARD} docextract import file"
        fi
    fi
    
    # import ${PACK} ${STANDARD} envelope resources
    if [ -d "${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/envelope/import" ]
    then
        java com.ibm.spe.core.utils.SPEImporter ${DBPROPS} quiet -import="${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/envelope/import"
        if [ $? -ne 0 ]
        then
            error "There was an error while loading ${PACK} ${STANDARD} envelope import file"
        fi       
    fi
    
    # import ${PACK} ${STANDARD} deenvelope maps
    if [ -d "${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/deenvelope/maps" ]
    then
        java com.ibm.spe.core.utils.SPEImporter ${DBPROPS} quiet -import="${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/deenvelope/maps"
        if [ $? -ne 0 ]
        then
            error "There was an error while loading ${PACK} ${STANDARD} deenvelope maps"
        fi       
    fi
    
    # import ${PACK} ${STANDARD} docextract maps
    if [ -d "${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/docextract/maps" ]
    then
        java com.ibm.spe.core.utils.SPEImporter ${DBPROPS} quiet -import="${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/docextract/maps"
        if [ $? -ne 0 ]
        then
            error "There was an error while loading ${PACK} ${STANDARD} docextract maps"
        fi
    fi
    
    # import ${PACK} ${STANDARD} envelope maps
    if [ -d "${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/envelope/maps" ]
    then
        java com.ibm.spe.core.utils.SPEImporter ${DBPROPS} quiet -import="${SPE_INSTALL_DIR}/examples/${PACK}/${STANDARD}/envelope/maps"
        if [ $? -ne 0 ]
        then
            error "There was an error while loading ${PACK} ${STANDARD} envelope maps"
        fi       
    fi
    
    echo
    echo "SPE ${PACK} pack example files were loaded successfully"
    echo
fi
