@ECHO OFF
REM ================================================================================
REM
REM Healthcare Pack for HIPAA X12
REM
REM Notices:
REM    LICENSED MATERIALS PROPERTY OF IBM AND HCL. 
REM       (c) Copyright International Business Machines Corp. 2006, 2017. 
REM       (c) Copyright HCL Technologies Ltd. 2017, 2019. All rights reserved. 
REM
REM    US Government Users Restricted Rights: 
REM       Use, duplication, or disclosure restricted by GSA ADP Schedule
REM       Contract with IBM Corp.  
REM		
REM ================================================================================
rem
rem USAGE: import_trees.bat  SEE ALSO: configurable_rules.bat
rem 
rem Intended to assist in customizing the (hipaa_x12_qualifier.dat) files
rem and the type trees used in the HIPAA compliance check application.
rem
rem For a complete description of how to configure HIPAA rules, refer to 
rem the Pack for healthcare documentation.
rem
rem EXECUTION:
rem
rem This execution will process the results from configuring rules. The
rem trees to be imported are located in the %configurable_rules_dir%\trees\.
rem After execution the final trees will be located in %configurable_rules_dir%\trees\
rem and should be copied to the following locations:
rem
rem    ITXA install_dir\Healthcare_Payer_vn.n.n\wtx\hipaa\trees 
rem    TX install_dir\packs\healthcare_vn.n.n.n\hipaa\trees
rem
rem NOTE:  The original trees installed with the HIPAA pack should be
rem        copied to a backup location before using these trees.
rem 
rem Please review all comments and instructions contained in this script 
rem and configurable_rules.bat
rem
rem ========================================================================

:BATCH_SETUP
	SETLOCAL
	SET this_script_name="%~nx0"
	TITLE Executing batch script file %this_script_name%
	SET dash=================================================================================

rem >>> This script will attempt to establish TX execution environment. Remove rem and set  
rem >>> TXHOME below ONLY if the script execution results cannot establish TX environment.
rem SET TXHOME=<TX product install path> 
	
REM Set debug_mode to NO to disable, DEBUG to enable
	SET debug_mode=NO
	IF /I [%1]==[DEBUG] SET debug_mode=DEBUG

	SET product_install_loc=unknown
	SET timport_exe=unknown
	SET tanalyze_exe=unknown

:START_BATCH_PROCESSING
	PUSHD "%~dp0"
	IF %debug_mode%==DEBUG (
		ECHO Start location is %CD%
		PAUSE
	)
	
	CD ..\
	SET "configurable_rules_dir=%CD%"
	IF %debug_mode%==DEBUG (
		ECHO configurable_rules_dir is defined as %configurable_rules_dir%
		PAUSE
	)

REM cd to the health care install directory	
	CD ..\..\
	SET "healthcare_install_loc=%CD%"
	IF %debug_mode%==DEBUG (
		ECHO healthcare_install_loc is defined as %healthcare_install_loc%
		PAUSE
	)
	
:TX_ENV

    IF defined TXHOME goto SKIP_TX_ENV

REM get current directory name from path
    SET current_directory=%CD%
    for %%j in (%current_directory%) do set FOLDERNAME=%%~nj
    IF %debug_mode%==DEBUG (
		ECHO current directory name is %FOLDERNAME%
		PAUSE
    )

REM determine if HC pack install with ITXA or TX
    SET ITXA=FALSE
    IF %FOLDERNAME%==wtx (
		SET ITXA=TRUE
		IF %debug_mode%==DEBUG (
			ECHO ITXA execution is TRUE
			PAUSE
		)
    )

REM cd to the product install directory
    CD ..\..\
    IF %ITXA%==TRUE (
		IF defined DTXHOME SET TXHOME=%DTXHOME%
    ) ELSE (
       SET TXHOME=%CD%
    )
			
    IF defined TXHOME goto SKIP_TX_ENV

	SET SPE_INSTALL_DIR=%CD%
    IF not exist "%SPE_INSTALL_DIR%\bin\spewtxenv.bat" goto :ERROR_ON_TX_ENVIRONMENT

REM call ITXA script to set TX environment
    IF %debug_mode%==DEBUG (
		ECHO call %SPE_INSTALL_DIR%\bin\spewtxenv.bat
		PAUSE
    )

	SET InSPEConsole=1
    call "%SPE_INSTALL_DIR%\bin\spewtxenv.bat"
	SET InSPEConsole=
	
    SET TXHOME=%DTXHOME%
    IF defined TXHOME (
	   goto SKIP_TX_ENV
    ) ELSE (
		goto :ERROR_ON_TX_ENVIRONMENT
	)
	
:SKIP_TX_ENV 
		
	SET "product_install_loc=%TXHOME%"
	CD %product_install_loc%
    IF %debug_mode%==DEBUG (
		ECHO Product install location is %product_install_loc%
		PAUSE
	)

	IF EXIST timport.exe (
		SET "tree_import_exe=%product_install_loc%\timport.exe"
		IF EXIST tanalyze.exe (
			SET "tree_analyze_exe=%product_install_loc%\tanalyze.exe"
		) ELSE (
			GOTO :PRODUCT_NOT_FOUND
		)
	) ELSE (	
		GOTO :PRODUCT_NOT_FOUND
	)

	CD %configurable_rules_dir%

	IF %debug_mode%==DEBUG (
		ECHO New location is %CD%
		ECHO tree_import_exe is defined as %tree_import_exe%
		ECHO tree_analyze_exe is defined as %tree_analyze_exe%
		PAUSE
	)

	ECHO %dash%
	ECHO:
	ECHO                      HIPAA X12 RULES CONFIGURATION
	ECHO                            IMPORT TYPE TREES
	ECHO:
	ECHO %dash%
	@ECHO OFF

	"%tree_import_exe%" "%configurable_rules_dir%\trees\hipaa_x12_type_2.mts" -LOG -FAIL -VERBOSE
	IF %ERRORLEVEL% NEQ 0  GOTO END
	"%tree_analyze_exe%" "%configurable_rules_dir%\trees\hipaa_x12_type_2.mtt" -L -S -LOG -FAIL -VERBOSE
	IF %ERRORLEVEL% NEQ 0  GOTO END

	"%tree_import_exe%" "%configurable_rules_dir%\trees\hipaa_x12.mts" -LOG -FAIL -VERBOSE 
	IF %ERRORLEVEL% NEQ 0  GOTO END
	"%tree_analyze_exe%" "%configurable_rules_dir%\trees\hipaa_x12.mtt" -L -S -LOG -FAIL -VERBOSE
	IF %ERRORLEVEL% NEQ 0  GOTO END

	"%tree_import_exe%" "%configurable_rules_dir%\trees\hipaa_x12_ruleless.mts" -LOG -FAIL -VERBOSE 
	IF %ERRORLEVEL% NEQ 0  GOTO END
	"%tree_analyze_exe%" "%configurable_rules_dir%\trees\hipaa_x12_ruleless.mtt" -L -S -LOG -FAIL -VERBOSE
	IF %ERRORLEVEL% NEQ 0  GOTO END

:CLEANUP
REM	DEL "%configurable_rules_dir%\trees\hipaa_x12_type_2.mts"
REM	DEL "%configurable_rules_dir%\trees\hipaa_x12.mts"
REM	DEL "%configurable_rules_dir%\trees\hipaa_x12_ruleless.mts"
	DEL "%configurable_rules_dir%\trees\*.bak"
	DEL "%configurable_rules_dir%\trees\*.dbe"
	GOTO END

:ERROR_ON_TX_ENVIRONMENT
	ECHO %dash%
	ECHO:
	ECHO: RESULTS:  CANNOT ESTABLISH TX ENVIRONMENT 
	ECHO: FILE NOT FOUND %SPE_INSTALL_DIR%\bin\spewtxenv.bat 
	ECHO:
	ECHO %dash%
	@ECHO OFF
	GOTO :END
	
:PRODUCT_NOT_FOUND
	ECHO %dash%
	ECHO:
	ECHO Key product executables were not found! 
	IF %tree_import_exe%==unknown ECHO     timport.exe was not found
	IF %tree_analyze_exe%==unknown ECHO     tanalyze.exe was not found
	ECHO Searching in the relative product install location 
	ECHO     %product_install_loc%
	ECHO:
	ECHO %dash%
	@ECHO OFF
	IF %debug_mode%==DEBUG PAUSE
	GOTO END

:END
	POPD
	IF %debug_mode%==DEBUG PAUSE

	IF %ERRORLEVEL% NEQ 0 (
		ECHO %dash%
		ECHO:
		ECHO  RESULTS:  IMPORT FAILED 
		ECHO:
		ECHO %dash%
		@ECHO OFF
		ENDLOCAL
		EXIT /B 1
	)

	ECHO %dash%
	ECHO:
	ECHO  RESULTS:  IMPORT SUCCESS  
	ECHO:
	ECHO %dash%
	@ECHO OFF
	ENDLOCAL
	EXIT /B
