//**    Copyright IBM Corporation 2006, 2015. All Rights Reserved.
//**
//** This software is the property of IBM Corporation and its
//** licensors and contains their confidential trade secrets.  Use, examination,
//** copying, transfer and disclosure to others, in whole or in part, are
//** prohibited except with the express prior written consent of
//** IBM Corporation.
//**
//** Sample program.
//** Demonstrates: How to use Type 7 JAVA exit with Standards Processing Engine.
//** 
//** Class: SPETestJExit 
//**
//** Validation Method: Type7_Checks 
//**
//** Provides the configuration properties for SPETestJExit. 
//**

package com.ibm.dtx.SPET7jexit;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Calendar;

public class SPETestJExit {

	T7ErrReturn T7ReturnErr = new T7ErrReturn();
	String ErrReturn = null;
	
	Log2 jLogger = new Log2();
	int ActiveLog = 0;
	int LogType = 0; // non-zero for jlog
	int LogActions = 0; // non-zero for debugging
	
	String EleDelim = "*";
	String RepDelim = "^";
	String SubDelim = ":";
	String SegDelim = "\r\n";
	String CurrDate = null;

	int ErrCount = 0;
	int SegCount = 0;
	int DataInError = 0;
	
	int errSegPos = 0;
	int errElePos = 0;
	int errSubElePos = 0;
	int errRepElePos = 0;

	// Error codes may be found in 5010X231A1 specification
	// OR in the Compliance Check tack_codetable.dat 
	int IK304_SegErrCode = 0;
	int IK403_EleErrCode = 0;

	String[] TriggerElements = null;
	int TriggerErrSegPos = 0;
	int TriggerErrElePos = 0;
	int TriggerErrSubElePos = 0;
	int TriggerErrRepElePos = 0;


	public SPETestJExit() {
	}

	//*
	// MAIN METHOD: Type7_Checks
	//
	// This example may use the jlog utilities or coded logging methods
	// SEE (this.LogType, this.LogActions) setting
	//
	//*

	public String Type7_Checks(String Delims, String hipaaData) {

		String Method = "Type7_Checks";

		try {

			this.DataInError = 0;
			this.ErrCount = 0;
			int hipaaTrx = 0;

			LogMsg("Execution = " + Method);

			// Get Delimiters
			int DelimLength = Delims.length();
			if (DelimLength < 3)
				LogMsg("Invalid Delimiters");

			this.EleDelim = Delims.substring(0, 1);
			this.RepDelim = Delims.substring(1, 2);
			this.SubDelim = Delims.substring(2, 3);
			if (DelimLength > 3) {
				this.SegDelim = Delims.substring(3);
			} else {
				this.SegDelim = "\r\n";
			}

			// Parse Segments
			String[] Segments = hipaaData.split("\\" + this.SegDelim);

			// Get Number of Segments
			this.SegCount = Segments.length;
			if (this.SegCount == 0)
				LogMsg("No Segments found");

			// Get Transaction ID
			String splitSTSeg = Segments[0];
			String[] Elements = splitSTSeg.split("\\" + this.EleDelim);
			hipaaTrx = Integer.parseInt(Elements[2]);

			switch (hipaaTrx) {
			case 270:
				X279A1_T270_Checks(Segments);
				break;
			case 837:
				T837_Checks(Segments);
				break;
			default:
				LogMsg("No Type7_Checks for transaction: " + Elements[2]);
			}
		}
		catch( Exception e )
		{

			this.LogActions = 1;
			System.err.println( e );
			LogMsg("**** EXCEPTION ERROR: " + Method + e.toString());
			StackTraceElement[] stack = e.getStackTrace();
			String exception = "";
			for (int jj = 0; jj < stack.length; jj++) {
				exception = exception + stack[jj].toString() + "\r\n";
			}

			LogMsg("**** TRACE: " + Method + "\r\n" + exception);
		}

		return this.ErrReturn;

	} // MAIN METHOD: end Type7_Checks

	//*
	//
	// METHOD: X279A1_T270_Checks
	//
	//*

	public void X279A1_T270_Checks(String[] Segments) {

		String Method = "X279A1_T270_Checks";

		try {

			this.DataInError = 0;
			this.ErrCount = 0;

			LogMsg("Execution = " + Method);

			// Begin Error Return XML Structure
			this.ErrReturn = T7ReturnErr.getUserErrStart();

			// Check EQ01 - X279A1 EQ01 must not repeat more than 99
			ChkEQ01(Segments);
			ChkResults(Method);

		}
		catch( Exception e )
		{

			this.LogActions = 1;
			System.err.println( e );
			LogMsg("**** EXCEPTION ERROR: " + Method + e.toString());
			StackTraceElement[] stack = e.getStackTrace();
			String exception = "";
			for (int jj = 0; jj < stack.length; jj++) {
				exception = exception + stack[jj].toString() + "\r\n";
			}

			LogMsg("**** TRACE: " + Method + "\r\n" + exception);
		}

	} // METHOD: end X279A1_T270_Checks

	//*
	//
	// METHOD: T837_Checks
	// 
	//*

	public void T837_Checks(String[] Segments) {

		String Method = "T837_Checks";

		try {

			this.DataInError = 0;

			LogMsg("Execution = " + Method);

			// Get System Date
			DateFormat dateFormat = new SimpleDateFormat("yyyyMMdd");
			Calendar cal = Calendar.getInstance();
			this.CurrDate = dateFormat.format(cal.getTime());

			// Begin Error Return XML Structure
			this.ErrReturn = T7ReturnErr.getUserErrStart();

			// Check Number of Claims greater than 100
			ChkNumClaims(Segments, 100);

			// Check DMG and DTP dates
			ChkDates(Segments, this.CurrDate);

			ChkResults(Method);

		}
		catch( Exception e )
		{

			this.LogActions = 1;
			System.err.println( e );
			LogMsg("**** EXCEPTION ERROR: " + Method + e.toString());
			StackTraceElement[] stack = e.getStackTrace();
			String exception = "";
			for (int jj = 0; jj < stack.length; jj++) {
				exception = exception + stack[jj].toString() + "\r\n";
			}

			LogMsg("**** TRACE: " + Method + "\r\n" + exception);
		}

	} // METHOD: end T837_Check_Dates

	//
	// ChkEQ01
	//
	public void ChkEQ01(String[] Segments) {

		String Method = "ChkEQ01";

		try {

			LogMsg("Execution = " + Method);

			int count = 0;
			int ii = 0;

			String[] Elements = null;
			String eleEQ01 = "";
			String ErrorMsg = null;
			String Error = this.ErrReturn;

			// Count EQ01
			for (ii = 0; ii < this.SegCount; ii++) {

				if (Segments[ii].startsWith("EQ" + this.EleDelim)) {

					count++;
					String splitEQSeg = Segments[ii];
					Elements = splitEQSeg.split("\\" + this.EleDelim);

					// Check count > 99
					if (count > 99) {
						this.IK304_SegErrCode = 4;
						ErrorMsg = "EQ segment repeats must not exceed 99.";
						break;
					}

					eleEQ01 = Elements[2];

					if (eleEQ01.contains(this.RepDelim)) {
						String[] splitEQ01 = eleEQ01.split("\\" + this.RepDelim);
						count = count + (splitEQ01.length - 1);

						// Check count < 99
						if (count > 99) {
							this.IK304_SegErrCode = 8;
							this.IK403_EleErrCode = 12;
							ErrorMsg = "EQ01 element repeats must not exceed 99.";
							this.errRepElePos = (99 - (count - splitEQ01.length)) + 1;
							break;
						}
					} // EQ01 repeats

				} // end EQ segment

			} // end for(ii)

			// Segment position relative to ST segment
			this.errSegPos = ii + 1;
			this.errSubElePos = 0;

			if (this.errRepElePos > 0)
				this.errElePos = 1;

			// Check count > 99
			if (count > 99) {
				this.DataInError = 1;
				this.ErrCount++;
				Error = SegLevel(Error, Elements, ErrorMsg);
			} 

			this.ErrReturn = Error;
		}

		catch( Exception e )
		{

			this.LogActions = 1;
			System.err.println( e );
			LogMsg("**** EXCEPTION ERROR: " + Method + e.toString());
			StackTraceElement[] stack = e.getStackTrace();
			String exception = "";
			for (int jj = 0; jj < stack.length; jj++) {
				exception = exception + stack[jj].toString() + "\r\n";
			}

			LogMsg("**** TRACE: " + Method + "\r\n" + exception);
		}

		return;

	} // end ChkEQ01

	//
	// X222A1 Check Number of Claims
	//
	public void ChkNumClaims(String[] Segments, int MaxNumClaims) {

		String Method = "ChkNumClaims";

		try {

			int count = 0;
			int ii = 0;

			String[] Elements = null;
			String ErrorMsg = null;
			String Error = this.ErrReturn;

			LogMsg("Execution = " + Method);

			// Count CLM segments
			for (ii = 0; ii < this.SegCount; ii++) {

				if (Segments[ii].startsWith("CLM" + this.EleDelim)) {

					count++;

					// Check count > MaxNumClaims
					if (count > MaxNumClaims) {
						this.DataInError = 1;
						String splitEQSeg = Segments[ii];
						Elements = splitEQSeg.split("\\" + this.EleDelim);
						this.IK304_SegErrCode = 4;
						ErrorMsg = "Number of Claims must not exceed " + 
								Integer.toString(MaxNumClaims);
						break;
					}

				} // end CLM segment

			} // end for(ii)

			// Segment position relative to ST segment
			this.errSegPos = ii + 1;
			this.errSubElePos = 0;

			// Generate Error Return information
			if (this.DataInError > 0) {
				this.ErrCount++;
				Error = SegLevel(Error, Elements, ErrorMsg);
			} 

			this.ErrReturn = Error;
		}

		catch( Exception e )
		{

			this.LogActions = 1;
			System.err.println( e );
			LogMsg("**** EXCEPTION ERROR: " + Method + e.toString());
			StackTraceElement[] stack = e.getStackTrace();
			String exception = "";
			for (int jj = 0; jj < stack.length; jj++) {
				exception = exception + stack[jj].toString() + "\r\n";
			}

			LogMsg("**** TRACE: " + Method + "\r\n" + exception);
		}

		return;

	} // end ChkNumClaims

	//
	// X222A1 DMG and DTP Dates not a future date and DTP Date less than DMG date
	// 

	public void ChkDates(String[] Segments, String CurrDate) {

		String Method = "ChkDates";

		try {

			int iCurrDate = Integer.parseInt(CurrDate);
			int iDateToCheck = 0;
			int iDMGDate = 0;

			int ii = 0;

			String Error = this.ErrReturn;
			String ErrorMsg = null;
			String DateFormat = null;
			String[] Elements = null;

			this.errSubElePos = 0;
			this.errRepElePos = 0;
			this.DataInError = 0;

			LogMsg("Execution = " + Method);

			// Check DMG and DTP dates
			for (ii = 0; ii < this.SegCount; ii++) {

				int SegInErr = 0;

				// X222A1 DTP Dates not a future date
				if (Segments[ii].startsWith("DMG" + this.EleDelim)) {

					String splitDMGSeg = Segments[ii];
					Elements = splitDMGSeg.split("\\" + this.EleDelim);
					this.TriggerElements = Elements;
					this.TriggerErrSegPos = ii + 1;
					this.TriggerErrElePos = 2;
					iDateToCheck = Integer.parseInt(Elements[3]);
					iDMGDate = iDateToCheck;

					// Check future date
					if (iDateToCheck > iCurrDate) {
						SegInErr = 1;
						this.errElePos = 2;
						this.IK304_SegErrCode = 8;
						this.IK403_EleErrCode = 8;
						ErrorMsg = "DMG02 date must not be a future date.";
					} // end Check future date

				} // end DMG segment

				// X222A1 DTP Dates not less than patient birthday
				if (Segments[ii].startsWith("DTP" + this.EleDelim)) {

					String splitDTPSeg = Segments[ii];
					Elements = splitDTPSeg.split("\\" + this.EleDelim);
					iDateToCheck = Integer.parseInt(Elements[4]);

					// Check future date
					if (iDateToCheck > iCurrDate) {
						SegInErr = 1;
						this.errElePos = 2;
						this.IK304_SegErrCode = 8;
						this.IK403_EleErrCode = 8;
						ErrorMsg = "DTP03 date must not be a future date.";
					} // end Check future date

					// Check less than DMG date
					DateFormat = Elements[3];
					if (DateFormat.startsWith("D8") && iDateToCheck < iDMGDate) {
						SegInErr = 1;
						this.errElePos = 3;
						this.IK304_SegErrCode = 8;
						this.IK403_EleErrCode = 8;
						ErrorMsg = "DTP03 date must not be less than DMG02.";
					} // end Check less than DMG date

				} // end DTP segment


				if (SegInErr > 0) {
					this.ErrCount++;
					// Segment position relative to ST segment
					this.errSegPos = ii + 1;
					Error = SegLevel(Error, Elements, ErrorMsg);
				}

			} // end for(ii)

			if (this.ErrCount > 0) {
				this.DataInError = 1;
			} else {
				Error = "";
			}

			this.ErrReturn = Error;
		}

		catch( Exception e )
		{

			this.LogActions = 1;
			System.err.println( e );
			LogMsg("**** EXCEPTION ERROR: " + Method + e.toString());
			StackTraceElement[] stack = e.getStackTrace();
			String exception = "";
			for (int jj = 0; jj < stack.length; jj++) {
				exception = exception + stack[jj].toString() + "\r\n";
			}

			LogMsg("**** TRACE: " + Method + "\r\n" + exception);
		}

		return;

	} // end ChkDates

	//
	// SegLevel
	//
	public String SegLevel(String XMLString, String[] Elements, String ErrMsg) {

		XMLString = XMLString + T7ReturnErr.getSegErrStart();
		XMLString = XMLString + T7ReturnErr.getSegName(Elements[0]);
		XMLString = XMLString + T7ReturnErr.getSegPos(this.errSegPos);
		XMLString = XMLString + T7ReturnErr.getSegLoopId(Elements[1]);
		XMLString = XMLString + T7ReturnErr.getSegErrCode(this.IK304_SegErrCode);
		XMLString = XMLString + T7ReturnErr.getErrMsg(ErrMsg);

		if (this.errElePos > 0) {
			XMLString = EleLevel(XMLString, Elements);
		}

		XMLString = XMLString + T7ReturnErr.getSegErrEnd();

		return XMLString;

	} // end SegLevel

	//
	// EleLevel
	//
	public String EleLevel(String XMLString, String[] Elements) {

		XMLString = XMLString + T7ReturnErr.getEleErrStart();
		XMLString = XMLString + T7ReturnErr.getElePos(this.errElePos);

		if (this.errSubElePos > 0) {
			XMLString = XMLString + T7ReturnErr.getSubElePos(this.errSubElePos);
		}

		if (this.errRepElePos > 0) {
			XMLString = XMLString + T7ReturnErr.getRepElePos(this.errRepElePos);
		}

		XMLString = XMLString + T7ReturnErr.getEleErrCode(this.IK403_EleErrCode);
		XMLString = XMLString
				+ T7ReturnErr.getEleValue(Elements[this.errElePos + 1]);

		XMLString = TriggerLevel(XMLString, Elements);

		XMLString = XMLString + T7ReturnErr.getEleErrEnd();

		return XMLString;

	} // end EleLevel

	//
	// TriggerLevel
	//
	public String TriggerLevel(String XMLString, String[] Elements) {

		if (this.TriggerElements == null) {
			this.TriggerElements = Elements;
			this.TriggerErrSegPos = this.errSegPos;
			this.TriggerErrElePos = this.errElePos;
			this.TriggerErrSubElePos = this.errSubElePos;
			this.TriggerErrRepElePos = this.errRepElePos;
		}

		XMLString = XMLString + T7ReturnErr.getTrigStart();
		XMLString = XMLString + T7ReturnErr.getTrigSegName(this.TriggerElements[0]);
		XMLString = XMLString + T7ReturnErr.getTrigSegPos(this.TriggerErrSegPos);
		XMLString = XMLString + T7ReturnErr.getTrigLoopId(TriggerElements[1]);

		if (this.TriggerErrElePos > 0) {
			XMLString = XMLString + T7ReturnErr.getTrigElePos(this.TriggerErrElePos);
		}

		if (this.TriggerErrSubElePos > 0) {
			XMLString = XMLString
					+ T7ReturnErr.getTrigSubElePos(this.TriggerErrSubElePos);
		}

		if (this.TriggerErrRepElePos > 0) {
			XMLString = XMLString
					+ T7ReturnErr.getTrigRepElePos(this.TriggerErrRepElePos);
		}

		XMLString = XMLString + T7ReturnErr.getTrigEnd();

		return XMLString;

	} // end TriggerLevel

	//
	// ChkResults
	//
	public void ChkResults(String Method) {

		if (this.DataInError > 0) { 
			// End Error Return XML Structure
			this.ErrReturn = this.ErrReturn + T7ReturnErr.getUserErrEnd();
			LogMsg("Return Error = " + ErrReturn.replaceAll("><", ">\r\n<"));

		} else {
			this.ErrReturn = "SPETestJExit::Type7_Checks::" + Method + "::Returning NO ERRORS";
			LogMsg("NO ERRORS:  " + Method);
		}
	} // end ChkResults

	//
	// LogMsg
	//

	public void LogMsg(String Message) {	

		if (this.LogActions > 0 && this.LogType != 0) {
			if (this.ActiveLog == 0) {
				this.ActiveLog = 1;
				jLogger.createJLog();
				jLogger.logActions("         START SPETestJExit          ");
			}

			jLogger.logActions(Message);

		}

		if (this.LogActions > 0 && this.LogType == 0) {
			if (this.ActiveLog == 0) {
				this.ActiveLog = 1;
				Log.deleteLog();
				Log.createHeader("         START SPETestJExit          ");
			}	

			Log.logActions(Message);
		}

	} // end LogMsg
} // end SPETestJExit