@echo off
@rem ==========================================================================
@rem == Licensed Materials - Property of IBM Corporation
@rem == (C) Copyright IBM Corporation 2019
@rem ==========================================================================
@rem Compiles maps and exports pack resources to be deployed to
@rem a runtime SPE server.
@rem Run this from an SPE console window. This is a WINDOWS ONLY script.
@rem ==========================================================================
@rem
if not defined InSPEConsole echo This command must be run in an SPE console session
if not defined InSPEConsole goto :EOF
Setlocal EnableDelayedExpansion

if     defined DTXHOME goto SKIP_WTX_ENV
if not exist "%SPE_INSTALL_DIR%\bin\spewtxenv.bat" echo Cannot establish WTX environment to compile WTX maps
if not exist "%SPE_INSTALL_DIR%\bin\spewtxenv.bat" goto :EOF
call spewtxenv
:SKIP_WTX_ENV 

set BITS=
set PLATFORM=
set RESOURCE=pack
set SPE_V_R=spe-9.0
set PACK_V_R_M=10.1.0
set PACK_V_R_M_F=10.1.0.0
set WTX_V_R_M=9.0.0
set PACK=hc

:READ_COMMAND_LINE_PARMS
if "%1"=="" goto GET_PLATFORM

rem read in -platform
if /i "%1"=="-platform" (
rem read in the -platform value
    set PLATFORM=%2
    shift
    goto READ_NEXT
)

rem read in -bits
if /i "%1"=="-bits" (
rem read in the -bits value: 32 or 64
    set BITS=%2
    shift
    goto READ_NEXT
)

rem read in -resource
if /i "%1"=="-resource" (
rem read in the -resource value: pack or maps
    set RESOURCE=%2
    shift
    goto READ_NEXT
)

rem help syntax
if /i "%1"=="/?" goto SYNTAX

:READ_NEXT
shift
goto READ_COMMAND_LINE_PARMS


:GET_PLATFORM
if defined PLATFORM goto VALIDATE_PLATFORM
echo.
echo Enter target: ALL, AIX, LINUX, WINDOWS
set /p PLATFORM=platform: 
if not defined PLATFORM goto GET_PLATFORM
rem We are in interactive mode, reset RESOURCE to show the prompt
set RESOURCE=

:VALIDATE_PLATFORM
rem convert PLATFORM to uppercase
for %%L IN (A B C D E F G H I J K L M N O P Q R S T U V W X Y Z) DO SET PLATFORM=!PLATFORM:%%L=%%L!
set PLATFORM_ORIGINAL=%PLATFORM%
if /i "%PLATFORM%"=="ALL" (
    set PLATFORM=AIX;LINUX;WINDOWS
    set SUPPORT=aix linux win
    set UNAME=AIX Linux Windows
    goto SET_DEFAULT_BITS
)
if /i "%PLATFORM%"=="AIX" (
    set SUPPORT=aix
    set UNAME=AIX
    goto SET_DEFAULT_BITS
)
if /i "%PLATFORM%"=="LINUX" (
    set SUPPORT=linux
    set UNAME=Linux
    goto SET_DEFAULT_BITS
)
if /i "%PLATFORM%"=="WINDOWS" (
    set SUPPORT=win
    set UNAME=Windows
    goto SET_DEFAULT_BITS
)

echo Invalid platform = "%PLATFORM%"
set PLATFORM=
goto GET_PLATFORM

:SET_DEFAULT_BITS
if defined BITS (
    if not "%BITS%"=="64" (
        echo.
        echo WARNING: setting BITS to the supported 64 instead of %BITS%
    )
)
set BITS=64
goto GET_RESOURCE

:GET_RESOURCE
rem The Pack Installer is delivering most of the files included in the full bundle (pack type)
if defined RESOURCE goto VALIDATE_RESOURCE
echo.
echo Enter the resource type to export: pack (default, press the enter key) or maps
set /p RESOURCE=resource: 
if not defined RESOURCE set RESOURCE=pack

:VALIDATE_RESOURCE
if "%RESOURCE%"=="pack" goto PLATFORM_BITS_OK
if "%RESOURCE%"=="maps" goto PLATFORM_BITS_OK
echo Invalid resource type = "%RESOURCE%"
set RESOURCE=
goto GET_RESOURCE

goto PLATFORM_BITS_OK

:PLATFORM_BITS_OK
cd %SPE_INSTALL_DIR%
if /i "%PLATFORM_ORIGINAL%"=="ALL" (
    set WORKDIR=spe_%PACK%_%RESOURCE%_for_%PLATFORM_ORIGINAL%
) else (
    set WORKDIR=spe_%PACK%_%RESOURCE%_for_%PLATFORM_ORIGINAL%_WTX_%BITS%bit
)
if exist %WORKDIR% rd /s /q %WORKDIR%
if exist %WORKDIR%.jar del %WORKDIR%.jar

rem START PACK SPECIFIC CODE
set TUSRDIR=%WORKDIR%\tpuiserver\usr\shared\resources
set PHCEDIR=%WORKDIR%\packs\hc\codelists\external
set PHCEEDIR=%WORKDIR%\packs\hc\codelists\external_examples
set PHBRDIR=%WORKDIR%\packs\hc\business_rules
set PHDDIR=%WORKDIR%\packs\hc\data
set PHMDIR=%WORKDIR%\packs\hc\maps
set REDIR=%WORKDIR%\resources\envelopes
set RMDIR=%WORKDIR%\resources\maps
set EHHDIR=%WORKDIR%\examples\hc\hipaa
set EHHDMDIR=%WORKDIR%\examples\hc\hipaa\deenvelope\maps
set EHHXMDIR=%WORKDIR%\examples\hc\hipaa\docextract\maps
set EHHEMDIR=%WORKDIR%\examples\hc\hipaa\envelope\maps
rem create directories that are not created by xcopy
if not exist "%SPE_INSTALL_DIR%"\%EHHDMDIR% mkdir "%SPE_INSTALL_DIR%"\%EHHDMDIR%
if not exist "%SPE_INSTALL_DIR%"\%EHHXMDIR% mkdir "%SPE_INSTALL_DIR%"\%EHHXMDIR%
if not exist "%SPE_INSTALL_DIR%"\%EHHEMDIR% mkdir "%SPE_INSTALL_DIR%"\%EHHEMDIR%
if "%RESOURCE%"=="maps" goto RESOURCE_MAPS

echo.
echo Copying envelopes...
xcopy resources\envelopes\X12\X12_*.xml %REDIR%\X12\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying autoenvelope maps...
xcopy resources\maps\autoenvelope\x12_* %RMDIR%\autoenvelope\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying schemas...
xcopy schema\SPE_IE_Standard_Types_HIPAA.xsd %WORKDIR%\schema\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy schema\SPE_IE_Standard_Types_X12.xsd %WORKDIR%\schema\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying xslt...
xcopy xslt\ie_si_to_spe_x12.xsl %WORKDIR%\xslt\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying UI file...
xcopy Healthcare_Payer_v%PACK_V_R_M%\tpui\X12envelope.xml %TUSRDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying software tag file
xcopy properties\version\ibm.com_IBM_Transformation_Extender_Pack_for_Healthcare_server-%PACK_V_R_M%.swidtag %WORKDIR%\properties\version\ /i
if ERRORLEVEL 1 goto ERROR
rem echo.
rem echo Copying fix pack tag file
rem xcopy properties\version\ibm.com_IBM_Transformation_Extender_Pack_for_Healthcare_server-%PACK_V_R_M_F%.swidtag %WORKDIR%\properties\version\ /i
rem if ERRORLEVEL 1 goto ERROR
echo.
echo Copying external codes...
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\external_codes\data\*.xml %PHCEDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\external_codes\examples\*.xml %PHCEEDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Copying business rules...
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\business_rules\*.xml %PHBRDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
rem example files
echo copying %PACK% example resources...
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\batchfile.txt %EHHDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\deenvelope\data\* %EHHDIR%\deenvelope\data\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\deenvelope\import\* %EHHDIR%\deenvelope\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\deenvelope\wtx_spe_adapter\* %EHHDIR%\deenvelope\wtx_spe_adapter\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\deenvelope\readme.txt %EHHDIR%\deenvelope\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\docextract\data\* %EHHDIR%\docextract\data\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\docextract\import\* %EHHDIR%\docextract\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\docextract\wtx_spe_adapter\* %EHHDIR%\docextract\wtx_spe_adapter\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\docextract\readme.txt %EHHDIR%\docextract\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\envelope\data\* %EHHDIR%\envelope\data\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\envelope\import\* %EHHDIR%\envelope\import\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\envelope\wtx_spe_adapter\* %EHHDIR%\envelope\wtx_spe_adapter\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\envelope\readme.txt %EHHDIR%\envelope\ /i
if ERRORLEVEL 1 goto ERROR
echo.

:RESOURCE_MAPS
echo.
echo Copying WTX support library...
if /i "%PLATFORM_ORIGINAL%"=="ALL" (
    for %%a in (%SUPPORT%) do (
        xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\platform_support\%%a\* %PHMDIR%\platform_support\%%a /i/s
        if ERRORLEVEL 1 goto ERROR
        xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\platform_support\%%a\* %WORKDIR%\platform_support\%%a /i/s
        if ERRORLEVEL 1 goto ERROR
    )
) else (
    xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\platform_support\%SUPPORT%\%BITS%\hcsvu.* %PHMDIR%\ /i
    if ERRORLEVEL 1 goto ERROR
    xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\platform_support\%SUPPORT%\%BITS%\hcsvu.* %WORKDIR%\ /i
    if ERRORLEVEL 1 goto ERROR
)
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\maps\t7_custom_user_error.xsd %PHMDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
echo Compiling Healthcare compliance check maps for %PLATFORM%
set MAP_DIR=%SPE_INSTALL_DIR%\Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\maps
pushd "%MAP_DIR%"
rem check for 9.0.0.* 
set MESSAGE=Could not find a supported version of WTX %WTX_V_R_M%
"%DTXHOME%"\dtxver "%DTXHOME%"\dtxver.exe | findstr "%WTX_V_R_M%\..*)" > nul
if ERRORLEVEL 1 goto ERROR
set MESSAGE=
mcompile compliance_check.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%PHMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
echo Copying data files...
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\data\hipaa_x12_*.dat %PHDDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\data\tack_codetable.dat %PHDDIR%\ /i
if ERRORLEVEL 1 goto ERROR
rem copy the same files to WORKDIR to be deployed to SPE_INSTALL_DIR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\data\hipaa_x12_*.dat %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
xcopy Healthcare_Payer_v%PACK_V_R_M%\wtx\hipaa\data\tack_codetable.dat %WORKDIR%\ /i
if ERRORLEVEL 1 goto ERROR
echo.
rem example maps
echo Compiling %PACK% example maps for %PLATFORM%
set MAP_DIR=%SPE_INSTALL_DIR%\Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\deenvelope\maps
pushd "%MAP_DIR%"
mcompile hipaa_837i_5010_to_medClaim.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EHHDMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
set MAP_DIR=%SPE_INSTALL_DIR%\Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\docextract\maps
pushd "%MAP_DIR%"
mcompile medclaim_docext.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EHHXMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
mcompile medClaim_to_hipaa_837i_5010_dx.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EHHXMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
set MAP_DIR=%SPE_INSTALL_DIR%\Healthcare_Payer_v%PACK_V_R_M%\examples\HIPAA\envelope\maps
pushd "%MAP_DIR%"
mcompile medClaim_to_hipaa_837i_5010.mms -A -E -P %PLATFORM% -O "%SPE_INSTALL_DIR%"\%EHHEMDIR%\*.mmc
if ERRORLEVEL 1 goto ERROR
popd
echo.
echo Copying example scripts...
if /i "%PLATFORM_ORIGINAL%"=="ALL" (
    xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\bin\spe*samples-packhc.bat %WORKDIR%\bin\ /i
    if ERRORLEVEL 1 goto ERROR
    xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\bin\spe*samples-packhc.sh %WORKDIR%\bin\ /i
    if ERRORLEVEL 1 goto ERROR
) else (
    if /i "%PLATFORM_ORIGINAL%"=="WINDOWS" (
        xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\bin\spe*samples-packhc.bat %WORKDIR%\bin\ /i
        if ERRORLEVEL 1 goto ERROR
    ) else (
        xcopy Healthcare_Payer_v%PACK_V_R_M%\examples\bin\spe*samples-packhc.sh %WORKDIR%\bin\ /i
        if ERRORLEVEL 1 goto ERROR
    )
)
echo.
rem END PACK SPECIFIC CODE

echo.
cd "%SPE_INSTALL_DIR%\jars"
echo Get the version of the local SPE core jar
if exist %SPE_V_R%-core.jar (
    java com.ibm.spe.core.utils.ReadJarManifest -name=%SPE_V_R%-core.jar -entry=com/ibm/spe/core/ -attribute=Implementation-Version > ..\%WORKDIR%\VERSION
    if ERRORLEVEL 1 goto ERROR    
)
echo.
echo Creating jar file...
cd "%SPE_INSTALL_DIR%\%WORKDIR%"
echo %UNAME%>UNAME
echo %BITS%>BITS
echo %PACK%>PACK
echo %PACK_V_R_M_F%>PACK_VERSION
echo %RESOURCE%>RESOURCE
java com.ibm.spe.core.utils.CreateJarFile -name="%SPE_INSTALL_DIR%\%WORKDIR%.jar" -input="."
if ERRORLEVEL 1 goto ERROR
cd %SPE_INSTALL_DIR%
if not exist %WORKDIR%.jar (
    echo.
    echo Failed to create %SPE_INSTALL_DIR%\%WORKDIR%.jar file!
    goto ERROR
)
echo.
echo Please transfer the %SPE_INSTALL_DIR%\%WORKDIR%.jar to the target SPE server and execute the spedeploy-packs script.
echo.
if exist %WORKDIR% rd /s /q %WORKDIR%
goto :EOF

:ERROR
echo.
echo.%MESSAGE%
echo.
echo There was an ERROR while processing command.
cd %SPE_INSTALL_DIR%
if exist %WORKDIR% rd /s /q %WORKDIR%
echo.
goto :EOF

:SYNTAX
echo Creates a resource jar bundle for %PACK% pack to be deployed to the target server.
echo.
echo speresource-pack%PACK%.bat -platform=target -bits=WTX bits [ -resource=pack, maps ]
echo.
echo Possible values for:  
echo -platform   ALL, AIX, LINUX, WINDOWS
echo -bits            64,   64,     64
echo -resource   pack (default) or maps
echo.
echo WARNING: for 64bit only WTX, the bits value will be ignored if specified.
echo.
goto :EOF
    
:EOF
