<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:xs="http://www.w3.org/2001/XMLSchema" 
	xmlns:si="http://www.stercomm.com/SI/SI_IE_Resources"
	version="1.0">

<!--
	####################################################################
	## Licensed Materials - Property of IBM
	## (C) Copyright IBM Corp. 2013 All Rights Reserved.
	## US Government Users Restricted Rights - Use, duplication or
	## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
	####################################################################

	This XSLT script is used to migrate SI import files to SPE format
	
	This should be included at the end of the is_si_to_spe.xsl script to filter out 
	X12-specific elements that may have been included in SI import files, but are
	not supported by SPE.
-->
	
<!-- Filter X12_ISA_IEA_Inbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'X12' and ../../si:TYPE = 'ISA IEA' and ../../si:FUNCTION = '1']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'InterchangeSenderIDQualifier' or
			./si:NAME = 'InterchangeReceiverIDQualifier' or
			./si:NAME = 'InterchangeControlVersionNumber' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'SpecifyInFileEncoding' or
			./si:NAME = 'SpecifyOutDocEncoding' or
			./si:NAME = 'InterchangeTestIndicator' or
			./si:NAME = 'PerformControlNumberSequenceCheck' or
			./si:NAME = 'PerformDuplicateControlNumberCheck' or
			./si:NAME = 'EDIPostProcessorMode' or
			./si:NAME = 'TA1ALAFormat' or			
			./si:NAME = 'GenCtrlNameOpts1' or
			./si:NAME = 'GenCtrlNumTestIndicator' or
			./si:NAME = 'InFileEncoding' or
			./si:NAME = 'OutDocEncoding' or
			./si:NAME = 'UseWtxComplianceChecking' or
			./si:NAME = 'GenerateAcknowledgement' or
			./si:NAME = 'AcceptNonCompliantInterchanges' or
			./si:NAME = 'ErrorBP' 
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
</xsl:template>

<!-- Filter X12_ISA_IEA_Outbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'X12' and ../../si:TYPE = 'ISA IEA' and ../../si:FUNCTION = '0']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'InterchangeAuthorizationInformationQualifier' or
			./si:NAME = 'InterchangeAuthorizationInformation' or
			./si:NAME = 'InterchangeSecurityInformationQualifier' or
			./si:NAME = 'InterchangeSecurityInformation' or
			./si:NAME = 'ReciprocateAuthAndSecurityMode' or
			./si:NAME = 'InterchangeSenderIDQualifier' or
			./si:NAME = 'InterchangeReceiverIDQualifier' or
			./si:NAME = 'InterchangeControlStandardsIdentifier' or
			./si:NAME = 'InterchangeControlVersionNumber' or
			./si:NAME = 'UseCorrelationOverrides' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'InterchangeAcknowledgmentRequested' or
			./si:NAME = 'InterchangeTestIndicator' or
			./si:NAME = 'AccepterLookupAlias' or
			./si:NAME = 'GenCtrlNameOpts1' or
			./si:NAME = 'GenCtrlNumTestIndicator' or
			./si:NAME = 'AcknowledgementOverdueTime' or
			./si:NAME = 'AcknowledgementOverdueTimeMinutes' or
			./si:NAME = 'UseWtxComplianceChecking' or
			./si:NAME = 'MaxDocsPerInterchange' or
			./si:NAME = 'LimitInterchangeSizeI' or
			./si:NAME = 'MaxInterchangeSizeI' or
			./si:NAME = 'InvokeBPForEachDoc' or
			./si:NAME = 'ElementSeparator' or
			./si:NAME = 'SegmentTerminator' or
			./si:NAME = 'SubElementSeparator' or
			./si:NAME = 'Streamed' or
			./si:NAME = 'EncodeDocument' or
			./si:NAME = 'Encoding' or
			./si:NAME = 'InvokeBPMode' or
			./si:NAME = 'BP' or
			./si:NAME = 'GenBPName1' or
			./si:NAME = 'BPNameStandard1' or
			./si:NAME = 'BPNameSenderQual1' or
			./si:NAME = 'BPNameSender1' or
			./si:NAME = 'BPNameReceiverQual1' or
			./si:NAME = 'BPNameReceiver1' or
			./si:NAME = 'BPNameTrnsSet1' or
			./si:NAME = 'BPNameICR1' or
			./si:NAME = 'BPNameGroupVersion1' or
			./si:NAME = 'BPNameTestIndicator1' or
			./si:NAME = 'UseBPName2' or
			./si:NAME = 'GenBPName2' or
			./si:NAME = 'BPNameStandard2' or
			./si:NAME = 'BPNameSenderQual2' or
			./si:NAME = 'BPNameSender2' or
			./si:NAME = 'BPNameReceiverQual2' or
			./si:NAME = 'BPNameReceiver2' or
			./si:NAME = 'BPNameTrnsSet2' or
			./si:NAME = 'BPNameICR2' or
			./si:NAME = 'BPNameGroupVersion2' or
			./si:NAME = 'BPNameTestIndicator2' or
			./si:NAME = 'UseBPName3' or
			./si:NAME = 'GenBPName3' or
			./si:NAME = 'BPNameStandard3' or
			./si:NAME = 'BPNameSenderQual3' or
			./si:NAME = 'BPNameSender3' or
			./si:NAME = 'BPNameReceiverQual3' or
			./si:NAME = 'BPNameReceiver3' or
			./si:NAME = 'BPNameTrnsSet3' or
			./si:NAME = 'BPNameICR3' or
			./si:NAME = 'BPNameGroupVersion3' or
			./si:NAME = 'BPNameTestIndicator3' or
			./si:NAME = 'UseBPName4' or
			./si:NAME = 'GenBPName4' or
			./si:NAME = 'BPNameStandard4' or
			./si:NAME = 'BPNameSenderQual4' or
			./si:NAME = 'BPNameSender4' or
			./si:NAME = 'BPNameReceiverQual4' or
			./si:NAME = 'BPNameReceiver4' or
			./si:NAME = 'BPNameTrnsSet4' or
			./si:NAME = 'BPNameICR4' or
			./si:NAME = 'BPNameGroupVersion4' or
			./si:NAME = 'BPNameTestIndicator4' or
			./si:NAME = 'ErrorIfBPNotFound' or
			./si:NAME = 'BPDataExtractMode' or
			./si:NAME = 'ExtractDirectory' or
			./si:NAME = 'ExtractFilename' or
			./si:NAME = 'ContractID' or
			./si:NAME = 'ContractName' or
			./si:NAME = 'ExtractMailbox' or 
			./si:NAME = 'ExtractMailboxMessageName'			
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
</xsl:template>

<!-- Filter X12_GS_GE_Inbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'X12' and ../../si:TYPE = 'GS GE' and ../../si:FUNCTION = '1']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'GroupFunctionalIDCode' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'GenCtrlNameOpts1' or
			./si:NAME = 'GenCtrlNumNameFuncGrpID1' or
			./si:NAME = 'GenCtrlNumNameGrpVersion1' or
			./si:NAME = 'GenCtrlNumTestIndicator1' or
			./si:NAME = 'UseCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNumNameFuncGrpID2' or
			./si:NAME = 'GenCtrlNumNameGrpVersion2' or
			./si:NAME = 'GenCtrlNumTestIndicator2' or
			./si:NAME = 'UseCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNumNameFuncGrpID3' or
			./si:NAME = 'GenCtrlNumNameGrpVersion3' or
			./si:NAME = 'GenCtrlNumTestIndicator3' or
			./si:NAME = 'GroupResponsibleAgencyCode' or
			./si:NAME = 'GroupVersionReleaseIDCode' or
			./si:NAME = 'GroupWithMultipleTransactionSetsNonCompliant' or
			./si:NAME = 'PerformControlNumberSequenceCheck' or
			./si:NAME = 'PerformDuplicateControlNumberCheck' or			
			./si:NAME = 'ErrorBP' or
			./si:NAME = 'AcceptNonCompliantGroups' or
			./si:NAME = 'GenerateAcknowledgement' or
			./si:NAME = 'AcknowledgementFormat' or
			./si:NAME = 'AcknowledgementDetailLevel' or
			./si:NAME = 'SendAckImmediately' or
			./si:NAME = '997ALAFormat'
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
</xsl:template>

<!-- Filter X12_GS_GE_Outbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'X12' and ../../si:TYPE = 'GS GE' and ../../si:FUNCTION = '0']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'NextEnvelope' or
			./si:NAME = 'TimeFormat' or
			./si:NAME = 'GroupFunctionalIDCode' or
			./si:NAME = 'UseCorrelationOverrides' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'GenCtrlNameOpts1' or
			./si:NAME = 'GenCtrlNumNameFuncGrpID1' or
			./si:NAME = 'GenCtrlNumNameGrpVersion1' or
			./si:NAME = 'GenCtrlNumTestIndicator1' or
			./si:NAME = 'UseCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNumNameFuncGrpID2' or
			./si:NAME = 'GenCtrlNumNameGrpVersion2' or
			./si:NAME = 'GenCtrlNumTestIndicator2' or
			./si:NAME = 'UseCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNumNameFuncGrpID3' or
			./si:NAME = 'GenCtrlNumNameGrpVersion3' or
			./si:NAME = 'GenCtrlNumTestIndicator3' or
			./si:NAME = 'GroupResponsibleAgencyCode' or
			./si:NAME = 'GroupVersionReleaseIDCode' or
			./si:NAME = 'ExpectAcknowledgement' or
			./si:NAME = 'AcknowledgementFormat' or
			./si:NAME = 'AcknowledgementOverdueTime' or
			./si:NAME = 'AcknowledgementOverdueTimeMinutes'
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
</xsl:template>
	
<!-- Filter X12_ST_SE_Inbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'X12' and ../../si:TYPE = 'ST SE' and ../../si:FUNCTION = '1']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'TransactionSetIDCode' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'GenCtrlNameOpts1' or
			./si:NAME = 'GenCtrlNumNameTrnsSetID1' or
			./si:NAME = 'GenCtrlNumNameICR1' or
			./si:NAME = 'GenCtrlNumNameGrpVersion1' or
			./si:NAME = 'GenCtrlNumTestIndicator1' or
			./si:NAME = 'UseCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNumNameTrnsSetID2' or
			./si:NAME = 'GenCtrlNumNameICR2' or
			./si:NAME = 'GenCtrlNumNameGrpVersion2' or
			./si:NAME = 'GenCtrlNumTestIndicator2' or
			./si:NAME = 'UseCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNumNameTrnsSetID3' or
			./si:NAME = 'GenCtrlNumNameICR3' or
			./si:NAME = 'GenCtrlNumNameGrpVersion3' or
			./si:NAME = 'GenCtrlNumTestIndicator3' or
			./si:NAME = 'ImplementationConventionReference' or
			./si:NAME = 'GroupVersionReleaseIDCode' or
			./si:NAME = 'InterchangeTestIndicator' or
			./si:NAME = 'PerformControlNumberSequenceCheck' or
			./si:NAME = 'PerformDuplicateControlNumberCheck' or
			./si:NAME = 'RetainEnvelope' or
			./si:NAME = 'BatchLikeTransactions' or
			./si:NAME = 'PerformComplianceCheck' or
			./si:NAME = 'MapNameMode' or
			./si:NAME = 'ComplianceCheckMapName' or
			./si:NAME = 'GenMapName1' or
			./si:NAME = 'MapNameStandard1' or
			./si:NAME = 'MapNameSender1' or
			./si:NAME = 'MapNameReceiver1' or
			./si:NAME = 'MapNameTrnsSet1' or
			./si:NAME = 'MapNameICR1' or
			./si:NAME = 'MapNameGroupVersion1' or
			./si:NAME = 'MapNameTestIndicator1' or
			./si:NAME = 'UseMapName2' or
			./si:NAME = 'GenMapName2' or
			./si:NAME = 'MapNameStandard2' or
			./si:NAME = 'MapNameSender2' or
			./si:NAME = 'MapNameReceiver2' or
			./si:NAME = 'MapNameTrnsSet2' or
			./si:NAME = 'MapNameICR2' or
			./si:NAME = 'MapNameGroupVersion2' or
			./si:NAME = 'MapNameTestIndicator2' or
			./si:NAME = 'UseMapName3' or
			./si:NAME = 'GenMapName3' or
			./si:NAME = 'MapNameStandard3' or
			./si:NAME = 'MapNameSender3' or
			./si:NAME = 'MapNameReceiver3' or
			./si:NAME = 'MapNameTrnsSet3' or
			./si:NAME = 'MapNameICR3' or
			./si:NAME = 'MapNameGroupVersion3' or
			./si:NAME = 'MapNameTestIndicator3' or
			./si:NAME = 'UseMapName4' or
			./si:NAME = 'GenMapName4' or
			./si:NAME = 'MapNameStandard4' or
			./si:NAME = 'MapNameSender4' or
			./si:NAME = 'MapNameReceiver4' or
			./si:NAME = 'MapNameTrnsSet4' or
			./si:NAME = 'MapNameICR4' or
			./si:NAME = 'MapNameGroupVersion4' or
			./si:NAME = 'MapNameTestIndicator4' or
			./si:NAME = 'ErrorIfMapNotFound' or
			./si:NAME = 'AcceptNonCompliantTransactions' or
			./si:NAME = 'KeepTranslatedDocument' or
			./si:NAME = 'ValidateOutput' or
			./si:NAME = 'InvokeBPMode' or
			./si:NAME = 'BPInvokeOrSetInPD' or
			./si:NAME = 'BP' or
			./si:NAME = 'GenBPName1' or
			./si:NAME = 'BPNameStandard1' or
			./si:NAME = 'BPNameSender1' or
			./si:NAME = 'BPNameReceiver1' or
			./si:NAME = 'BPNameTrnsSet1' or
			./si:NAME = 'BPNameICR1' or
			./si:NAME = 'BPNameGroupVersion1' or
			./si:NAME = 'BPNameTestIndicator1' or
			./si:NAME = 'UseBPName2' or
			./si:NAME = 'GenBPName2' or
			./si:NAME = 'BPNameStandard2' or
			./si:NAME = 'BPNameSender2' or
			./si:NAME = 'BPNameReceiver2' or
			./si:NAME = 'BPNameTrnsSet2' or
			./si:NAME = 'BPNameICR2' or
			./si:NAME = 'BPNameGroupVersion2' or
			./si:NAME = 'BPNameTestIndicator2' or
			./si:NAME = 'UseBPName3' or
			./si:NAME = 'GenBPName3' or
			./si:NAME = 'BPNameStandard3' or
			./si:NAME = 'BPNameSender3' or
			./si:NAME = 'BPNameReceiver3' or
			./si:NAME = 'BPNameTrnsSet3' or
			./si:NAME = 'BPNameICR3' or
			./si:NAME = 'BPNameGroupVersion3' or
			./si:NAME = 'BPNameTestIndicator3' or
			./si:NAME = 'UseBPName4' or
			./si:NAME = 'GenBPName4' or
			./si:NAME = 'BPNameStandard4' or
			./si:NAME = 'BPNameSender4' or
			./si:NAME = 'BPNameReceiver4' or
			./si:NAME = 'BPNameTrnsSet4' or
			./si:NAME = 'BPNameICR4' or
			./si:NAME = 'BPNameGroupVersion4' or
			./si:NAME = 'BPNameTestIndicator4' or
			./si:NAME = 'ErrorIfBPNotFound' or
			./si:NAME = 'BPDataExtractMode' or
			./si:NAME = 'ExtractDirectory' or
			./si:NAME = 'ExtractFilename' or
			./si:NAME = 'ErrorBPNameMode' or
			./si:NAME = 'ErrorBP' or
			./si:NAME = 'GenErrorBPName1' or
			./si:NAME = 'ErrorBPNameStandard1' or
			./si:NAME = 'ErrorBPNameSender1' or
			./si:NAME = 'ErrorBPNameReceiver1' or
			./si:NAME = 'ErrorBPNameTrnsSet1' or
			./si:NAME = 'ErrorBPNameICR1' or
			./si:NAME = 'ErrorBPNameGroupVersion1' or
			./si:NAME = 'ErrorBPNameTestIndicator1' or
			./si:NAME = 'UseErrorBPName2' or
			./si:NAME = 'GenErrorBPName2' or
			./si:NAME = 'ErrorBPNameStandard2' or
			./si:NAME = 'ErrorBPNameSender2' or
			./si:NAME = 'ErrorBPNameReceiver2' or
			./si:NAME = 'ErrorBPNameTrnsSet2' or
			./si:NAME = 'ErrorBPNameICR2' or
			./si:NAME = 'ErrorBPNameGroupVersion2' or
			./si:NAME = 'ErrorBPNameTestIndicator2' or
			./si:NAME = 'UseErrorBPName3' or
			./si:NAME = 'GenErrorBPName3' or
			./si:NAME = 'ErrorBPNameStandard3' or
			./si:NAME = 'ErrorBPNameSender3' or
			./si:NAME = 'ErrorBPNameReceiver3' or
			./si:NAME = 'ErrorBPNameTrnsSet3' or
			./si:NAME = 'ErrorBPNameICR3' or
			./si:NAME = 'ErrorBPNameGroupVersion3' or
			./si:NAME = 'ErrorBPNameTestIndicator3' or
			./si:NAME = 'UseErrorBPName4' or
			./si:NAME = 'GenErrorBPName4' or
			./si:NAME = 'ErrorBPNameStandard4' or
			./si:NAME = 'ErrorBPNameSender4' or
			./si:NAME = 'ErrorBPNameReceiver4' or
			./si:NAME = 'ErrorBPNameTrnsSet4' or
			./si:NAME = 'ErrorBPNameICR4' or
			./si:NAME = 'ErrorBPNameGroupVersion4' or
			./si:NAME = 'ErrorBPNameTestIndicator4' or
			./si:NAME = 'ErrorIfErrorBPNotFound' or
			./si:NAME = 'ContractID' or
			./si:NAME = 'ContractName' or						
			./si:NAME = 'ExtractMailbox' or
			./si:NAME = 'ExtractMailboxMessageName'
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
</xsl:template>

<!-- Filter X12_ST_SE_Outbound parms -->
<xsl:template match ="*[local-name()='ENVELOPE_PARM' and ../../si:STANDARD = 'X12' and ../../si:TYPE = 'ST SE' and ../../si:FUNCTION = '0']" >
	<!-- If one of the allowed parms, use conversion template in main ie_si_to_spe.xsl transform -->
	<xsl:if test="(
			./si:NAME = 'NextEnvelope' or
			./si:NAME = 'TransactionSenderIDQualifier' or
			./si:NAME = 'TransactionReceiverIDQualifier' or
			./si:NAME = 'TransactionSetIDCode' or
			./si:NAME = 'UseCorrelationOverrides' or
			./si:NAME = 'global_control_no' or
			./si:NAME = 'GenCtrlNameOpts1' or
			./si:NAME = 'GenCtrlNumNameTrnsSetID1' or
			./si:NAME = 'GenCtrlNumNameICR1' or
			./si:NAME = 'GenCtrlNumNameGrpVersion1' or
			./si:NAME = 'GenCtrlNumTestIndicator1' or
			./si:NAME = 'UseCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNameOpts2' or
			./si:NAME = 'GenCtrlNumNameTrnsSetID2' or
			./si:NAME = 'GenCtrlNumNameICR2' or
			./si:NAME = 'GenCtrlNumNameGrpVersion2' or
			./si:NAME = 'GenCtrlNumTestIndicator2' or
			./si:NAME = 'UseCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNameOpts3' or
			./si:NAME = 'GenCtrlNumNameTrnsSetID3' or
			./si:NAME = 'GenCtrlNumNameICR3' or
			./si:NAME = 'GenCtrlNumNameGrpVersion3' or
			./si:NAME = 'GenCtrlNumTestIndicator3' or
			./si:NAME = 'ImplementationConventionReference' or
			./si:NAME = 'AccepterLookupAlias' or
			./si:NAME = 'PerformHIPAACompCheck' or
			./si:NAME = 'LimitInterchangeSizeT' or
			./si:NAME = 'MaxInterchangeSizeT' or
			./si:NAME = 'MapNameMode' or
			./si:NAME = 'MapName' or
			./si:NAME = 'ValidateInput' or
			./si:NAME = 'ValidateOutput' or
			./si:NAME = 'GenMapName1' or
			./si:NAME = 'MapNameStandard1' or
			./si:NAME = 'MapNameSenderQual1' or
			./si:NAME = 'MapNameSender1' or
			./si:NAME = 'MapNameReceiverQual1' or
			./si:NAME = 'MapNameReceiver1' or
			./si:NAME = 'MapNameTrnsSet1' or
			./si:NAME = 'MapNameICR1' or
			./si:NAME = 'MapNameGroupVersion1' or
			./si:NAME = 'MapNameTestIndicator1' or
			./si:NAME = 'UseMapName2' or
			./si:NAME = 'GenMapName2' or
			./si:NAME = 'MapNameStandard2' or
			./si:NAME = 'MapNameSenderQual2' or
			./si:NAME = 'MapNameSender2' or
			./si:NAME = 'MapNameReceiverQual2' or
			./si:NAME = 'MapNameReceiver2' or
			./si:NAME = 'MapNameTrnsSet2' or
			./si:NAME = 'MapNameICR2' or
			./si:NAME = 'MapNameGroupVersion2' or
			./si:NAME = 'MapNameTestIndicator2' or
			./si:NAME = 'UseMapName3' or
			./si:NAME = 'GenMapName3' or
			./si:NAME = 'MapNameStandard3' or
			./si:NAME = 'MapNameSenderQual3' or
			./si:NAME = 'MapNameSender3' or
			./si:NAME = 'MapNameReceiverQual3' or
			./si:NAME = 'MapNameReceiver3' or
			./si:NAME = 'MapNameTrnsSet3' or
			./si:NAME = 'MapNameICR3' or
			./si:NAME = 'MapNameGroupVersion3' or
			./si:NAME = 'MapNameTestIndicator3' or
			./si:NAME = 'UseMapName4' or
			./si:NAME = 'GenMapName4' or
			./si:NAME = 'MapNameStandard4' or
			./si:NAME = 'MapNameSenderQual4' or
			./si:NAME = 'MapNameSender4' or
			./si:NAME = 'MapNameReceiverQual4' or
			./si:NAME = 'MapNameReceiver4' or
			./si:NAME = 'MapNameTrnsSet4' or
			./si:NAME = 'MapNameICR4' or
			./si:NAME = 'MapNameGroupVersion4' or
			./si:NAME = 'MapNameTestIndicator4' or
			./si:NAME = 'ErrorIfMapNotFound'
			)">
		<xsl:apply-templates select="." mode="convert"/>
	</xsl:if>
</xsl:template>
  
<!-- 
	X12 ENVELOPE_ID processing.  Adds the new envelope DESCRIPTION field as follows:
	Interchange level - use standard type (X12)
	Group level - use GroupFunctionalIDCode envelope parm
	Transaction level - TransactionSetIDCode envelope parm	
-->
<xsl:template match="*[local-name()='ENVELOPE_ID' and ../si:STANDARD = 'X12']">
	<xsl:element name="ENVELOPE_ID" namespace="{$spe-namespace}">
		<xsl:apply-templates select="@* | node()"/>
	</xsl:element>
	<!-- Add DESCRIPTION -->
	<xsl:element name="DESCRIPTION" namespace="{$spe-namespace}" >
		<xsl:choose>
			<xsl:when test="../si:TYPE = 'ST SE'">
				<xsl:value-of select="../si:ENVELOPE_PARMS/si:ENVELOPE_PARM/si:VALUE[../si:NAME/text() = 'TransactionSetIDCode']"/>
			</xsl:when>
			<xsl:when test="../si:TYPE = 'GS GE'">
				<xsl:value-of select="../si:ENVELOPE_PARMS/si:ENVELOPE_PARM/si:VALUE[../si:NAME/text() = 'GroupFunctionalIDCode']"/>
			</xsl:when>
			<xsl:when test="../si:TYPE = 'ISA IEA'">
				<xsl:value-of select="../si:STANDARD"/>
			</xsl:when>
		</xsl:choose>
	</xsl:element>
</xsl:template>

</xsl:stylesheet>
